import bpy
import rna_keymap_ui
from . import __package__ as base_package

def get_addon_path(addon_name):
    for addon in bpy.context.preferences.addons:
        if str(addon_name) in addon.module:
            return addon.module
        
def get_addon_prefs():
    addon_prefs = bpy.context.preferences.addons[base_package]
    return addon_prefs.preferences

keymap_items = [
    ['Object Mode', 'EMPTY', 'wm.call_menu_pie', 'A', 'PRESS', True, False, False, 'NON_DESTRUCTIVE_PRIMITIVES_MT_add_objects_pie_menu'],
]
def draw_keymap(self, context):
    def get_pie_menu_hotkey(km, kmi_name, kmi_value):
        for i, km_item in enumerate(km.keymap_items):
            if km.keymap_items.keys()[i] == kmi_name:
                if km.keymap_items[i].properties.name == kmi_value:
                    return km_item

    def get_operator_hotkey(km, kmi_name):
        for i, km_item in enumerate(km.keymap_items):
            if km.keymap_items.keys()[i] == kmi_name:
                return km_item

    wm = context.window_manager
    kc = wm.keyconfigs.user
    layout = self.layout
    box = layout.box()
    split = box.split()
    col = split.column()

    for km_item in keymap_items:
        km = kc.keymaps[km_item[0]]
        operator = km_item[2]
        if operator == 'wm.call_menu_pie':
            value = km_item[-1]
            kmi = get_pie_menu_hotkey(km, 'wm.call_menu_pie', value)
        else:
            kmi = get_operator_hotkey(km, operator)
        if kmi:
            col.context_pointer_set("keymap", km)
            rna_keymap_ui.draw_kmi([], kc, km, kmi, col, 0)

def keymap_register(wm):
    keymaps = []
    for items in keymap_items:
        (area_name, space,
            item_id, button, value,
            shift_state, ctrl_state, alt_state,
            pie_name) = items
        km = wm.keyconfigs.addon.keymaps.new(name=area_name, space_type=space)
        kmi = km.keymap_items.new(
            item_id, button, value,
            shift=shift_state, ctrl=ctrl_state, alt=alt_state
        )
        if pie_name:
            kmi.properties.name = pie_name
        keymaps.append((km, kmi))
    return keymaps
